@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
-#define _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
+#ifndef D_ABSTRACT_PROXY_REQUEST_COMMAND_H
+#define D_ABSTRACT_PROXY_REQUEST_COMMAND_H
 
 #include "AbstractCommand.h"
 
@@ -44,30 +44,35 @@ class SocketCore;
 
 class AbstractProxyRequestCommand : public AbstractCommand {
 private:
-  SharedHandle<Request> proxyRequest_;
+  std::shared_ptr<Request> proxyRequest_;
+
+  std::shared_ptr<HttpConnection> httpConnection_;
 
-  SharedHandle<HttpConnection> httpConnection_;
 protected:
-  virtual bool executeInternal();
+  virtual bool executeInternal() CXX11_OVERRIDE;
 
-  const SharedHandle<HttpConnection>& getHttpConnection() const
+  const std::shared_ptr<HttpConnection>& getHttpConnection() const
   {
     return httpConnection_;
   }
+
+  const std::shared_ptr<Request>& getProxyRequest() const
+  {
+    return proxyRequest_;
+  }
+
 public:
-  AbstractProxyRequestCommand(cuid_t cuid,
-                              const SharedHandle<Request>& req,
-                              const SharedHandle<FileEntry>& fileEntry,
-                              RequestGroup* requestGroup,
-                              DownloadEngine* e,
-                              const SharedHandle<Request>& proxyRequest,
-                              const SharedHandle<SocketCore>& s);
+  AbstractProxyRequestCommand(cuid_t cuid, const std::shared_ptr<Request>& req,
+                              const std::shared_ptr<FileEntry>& fileEntry,
+                              RequestGroup* requestGroup, DownloadEngine* e,
+                              const std::shared_ptr<Request>& proxyRequest,
+                              const std::shared_ptr<SocketCore>& s);
 
   virtual ~AbstractProxyRequestCommand();
 
-  virtual Command* getNextCommand() = 0;
+  virtual std::unique_ptr<Command> getNextCommand() = 0;
 };
 
 } // namespace aria2
 
-#endif // _D_ABSTRACT_PROXY_REQUEST_COMMAND_H_
+#endif // D_ABSTRACT_PROXY_REQUEST_COMMAND_H
