@@ -32,13 +32,15 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BT_MESSAGE_DISPATCHER_H_
-#define _D_BT_MESSAGE_DISPATCHER_H_
+#ifndef D_BT_MESSAGE_DISPATCHER_H
+#define D_BT_MESSAGE_DISPATCHER_H
 
 #include "common.h"
-#include "SharedHandle.h"
+
+#include <vector>
+#include <memory>
+
 #include "RequestSlot.h"
-#include <deque>
 
 namespace aria2 {
 
@@ -47,20 +49,20 @@ class BtMessage;
 
 class BtMessageDispatcher {
 public:
-  virtual ~BtMessageDispatcher() {}
+  virtual ~BtMessageDispatcher() = default;
 
-  virtual void addMessageToQueue(const SharedHandle<BtMessage>& btMessage) = 0;
-
-  virtual void
-  addMessageToQueue(const std::deque<SharedHandle<BtMessage> >& btMessages) = 0;
+  virtual void addMessageToQueue(std::unique_ptr<BtMessage> btMessage) = 0;
 
   virtual void sendMessages() = 0;
 
-  virtual void doCancelSendingPieceAction(size_t index, uint32_t begin, size_t length) = 0;
+  virtual void doCancelSendingPieceAction(size_t index, int32_t begin,
+                                          int32_t length) = 0;
 
-  virtual void doCancelSendingPieceAction(const SharedHandle<Piece>& piece) = 0;
+  virtual void
+  doCancelSendingPieceAction(const std::shared_ptr<Piece>& piece) = 0;
 
-  virtual void doAbortOutstandingRequestAction(const SharedHandle<Piece>& piece) = 0;
+  virtual void
+  doAbortOutstandingRequestAction(const std::shared_ptr<Piece>& piece) = 0;
 
   virtual void doChokedAction() = 0;
 
@@ -76,18 +78,16 @@ public:
 
   virtual bool isOutstandingRequest(size_t index, size_t blockIndex) = 0;
 
-  virtual RequestSlot getOutstandingRequest(size_t index, uint32_t begin, size_t length) = 0;
+  virtual const RequestSlot* getOutstandingRequest(size_t index, int32_t begin,
+                                                   int32_t length) = 0;
 
-  virtual void removeOutstandingRequest(const RequestSlot& slot) = 0;
+  virtual void removeOutstandingRequest(const RequestSlot* slot) = 0;
 
-  virtual void addOutstandingRequest(const RequestSlot& slot) = 0;
+  virtual void addOutstandingRequest(std::unique_ptr<RequestSlot> slot) = 0;
 
   virtual size_t countOutstandingUpload() = 0;
 };
 
-typedef SharedHandle<BtMessageDispatcher> BtMessageDispatcherHandle;
-typedef WeakHandle<BtMessageDispatcher> BtMessageDispatcherWeakHandle;
-
 } // namespace aria2
 
-#endif // _D_BT_MESSAGE_DISPATCHER_H_
+#endif // D_BT_MESSAGE_DISPATCHER_H
