@@ -38,8 +38,8 @@
 #include "common.h"
 
 #include <map>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "RequestGroup.h"
 
 namespace aria2 {
@@ -51,58 +51,54 @@ class BtRuntime;
 class BtProgressInfoFile;
 class DownloadContext;
 class LpdMessageReceiver;
+class UDPTrackerClient;
 
 struct BtObject {
-  SharedHandle<DownloadContext> downloadContext_;
-  SharedHandle<PieceStorage> pieceStorage_;
-  SharedHandle<PeerStorage> peerStorage_;
-  SharedHandle<BtAnnounce> btAnnounce_;
-  SharedHandle<BtRuntime> btRuntime_;
-  SharedHandle<BtProgressInfoFile> btProgressInfoFile_;
+  std::shared_ptr<DownloadContext> downloadContext;
+  std::shared_ptr<PieceStorage> pieceStorage;
+  std::shared_ptr<PeerStorage> peerStorage;
+  std::shared_ptr<BtAnnounce> btAnnounce;
+  std::shared_ptr<BtRuntime> btRuntime;
+  std::shared_ptr<BtProgressInfoFile> btProgressInfoFile;
 
-  BtObject(const SharedHandle<DownloadContext>& downloadContext,
-           const SharedHandle<PieceStorage>& pieceStorage,
-           const SharedHandle<PeerStorage>& peerStorage,
-           const SharedHandle<BtAnnounce>& btAnnounce,
-           const SharedHandle<BtRuntime>& btRuntime,
-           const SharedHandle<BtProgressInfoFile>& btProgressInfoFile);
+  BtObject(const std::shared_ptr<DownloadContext>& downloadContext,
+           const std::shared_ptr<PieceStorage>& pieceStorage,
+           const std::shared_ptr<PeerStorage>& peerStorage,
+           const std::shared_ptr<BtAnnounce>& btAnnounce,
+           const std::shared_ptr<BtRuntime>& btRuntime,
+           const std::shared_ptr<BtProgressInfoFile>& btProgressInfoFile);
 
   BtObject();
-
-  BtObject(const BtObject& c);
-
-  ~BtObject();
-
-  BtObject& operator=(const BtObject& c);
-
-  bool isNull() const;
 };
 
 class BtRegistry {
 private:
-  std::map<a2_gid_t, BtObject> pool_;
+  std::map<a2_gid_t, std::unique_ptr<BtObject>> pool_;
   uint16_t tcpPort_;
-  SharedHandle<LpdMessageReceiver> lpdMessageReceiver_;
+  // This is UDP port for DHT and UDP tracker. But currently UDP
+  // tracker is not supported in IPv6.
+  uint16_t udpPort_;
+  std::shared_ptr<LpdMessageReceiver> lpdMessageReceiver_;
+  std::shared_ptr<UDPTrackerClient> udpTrackerClient_;
+
 public:
   BtRegistry();
-  ~BtRegistry();
 
-  SharedHandle<DownloadContext>
+  const std::shared_ptr<DownloadContext>&
   getDownloadContext(a2_gid_t gid) const;
 
-  SharedHandle<DownloadContext>
+  const std::shared_ptr<DownloadContext>&
   getDownloadContext(const std::string& infoHash) const;
 
-  void put(a2_gid_t gid, const BtObject& obj);
+  void put(a2_gid_t gid, std::unique_ptr<BtObject> obj);
 
-  BtObject get(a2_gid_t gid) const;
+  BtObject* get(a2_gid_t gid) const;
 
-  template<typename OutputIterator>
+  template <typename OutputIterator>
   OutputIterator getAllDownloadContext(OutputIterator dest)
   {
-    for(std::map<a2_gid_t, BtObject>::const_iterator i = pool_.begin(),
-          eoi = pool_.end(); i != eoi; ++i) {
-      *dest++ = (*i).second.downloadContext_;
+    for (auto& kv : pool_) {
+      *dest++ = kv.second->downloadContext;
     }
     return dest;
   }
@@ -111,20 +107,24 @@ public:
 
   bool remove(a2_gid_t gid);
 
-  void setTcpPort(uint16_t port)
-  {
-    tcpPort_ = port;
-  }
-  uint16_t getTcpPort() const
-  {
-    return tcpPort_;
-  }
+  void setTcpPort(uint16_t port) { tcpPort_ = port; }
+  uint16_t getTcpPort() const { return tcpPort_; }
 
-  void setLpdMessageReceiver(const SharedHandle<LpdMessageReceiver>& receiver);
-  const SharedHandle<LpdMessageReceiver>& getLpdMessageReceiver() const
+  void setUdpPort(uint16_t port) { udpPort_ = port; }
+  uint16_t getUdpPort() const { return udpPort_; }
+
+  void
+  setLpdMessageReceiver(const std::shared_ptr<LpdMessageReceiver>& receiver);
+  const std::shared_ptr<LpdMessageReceiver>& getLpdMessageReceiver() const
   {
     return lpdMessageReceiver_;
   }
+
+  void setUDPTrackerClient(const std::shared_ptr<UDPTrackerClient>& tracker);
+  const std::shared_ptr<UDPTrackerClient>& getUDPTrackerClient() const
+  {
+    return udpTrackerClient_;
+  }
 };
 
 } // namespace aria2
