@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H_
-#define _D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H_
+#ifndef D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H
+#define D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H
 
 #include "SequentialDispatcherCommand.h"
 #include "CheckIntegrityMan.h"
@@ -42,18 +42,17 @@ namespace aria2 {
 
 class CheckIntegrityEntry;
 
-class CheckIntegrityDispatcherCommand :
-    public SequentialDispatcherCommand<CheckIntegrityEntry> {
+class CheckIntegrityDispatcherCommand
+    : public SequentialDispatcherCommand<CheckIntegrityEntry> {
 public:
-  CheckIntegrityDispatcherCommand
-  (cuid_t cuid,
-   const SharedHandle<CheckIntegrityMan>& checkMan,
-   DownloadEngine* e);
+  CheckIntegrityDispatcherCommand(cuid_t cuid, CheckIntegrityMan* checkMan,
+                                  DownloadEngine* e);
+
 protected:
-  virtual Command* createCommand
-  (const SharedHandle<CheckIntegrityEntry>& entry);
+  virtual std::unique_ptr<Command>
+  createCommand(CheckIntegrityEntry* entry) CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H_
+#endif // D_CHECK_INTEGRITY_DISPATCHER_COMMAND_H
