@@ -32,22 +32,28 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_CREATE_REQUEST_COMMAND_H_
-#define _D_CREATE_REQUEST_COMMAND_H_
+#ifndef D_CREATE_REQUEST_COMMAND_H
+#define D_CREATE_REQUEST_COMMAND_H
 
 #include "AbstractCommand.h"
 
 namespace aria2 {
 
-class CreateRequestCommand:public AbstractCommand {
+// CreateRequestCommand selects URI using URISelector object and
+// create Request object with the selected URI. Then create subsequent
+// command using
+// InitiateConnectionCommandFactory. InitiateConnectionCommandFactory
+// creates Command based on the protocol of selected URI.  If there is
+// no URI available, then throws exceptions.
+class CreateRequestCommand : public AbstractCommand {
 public:
-  CreateRequestCommand(cuid_t cuid,
-                       RequestGroup* requestGroup,
+  CreateRequestCommand(cuid_t cuid, RequestGroup* requestGroup,
                        DownloadEngine* e);
+
 protected:
-  virtual bool executeInternal();
+  virtual bool executeInternal() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
 
-#endif // _D_CREATE_REQUEST_COMMAND_H_
+#endif // D_CREATE_REQUEST_COMMAND_H
