@@ -36,10 +36,14 @@
 #define D_DH_KEY_EXCHANGE_H
 
 #include "common.h"
-#ifdef HAVE_LIBGCRYPT
-# include "LibgcryptDHKeyExchange.h"
-#elif HAVE_LIBSSL
-# include "LibsslDHKeyExchange.h"
-#endif // HAVE_LIBSSL
+#ifdef USE_INTERNAL_BIGNUM
+#include "InternalDHKeyExchange.h"
+#elif HAVE_LIBGMP
+#include "LibgmpDHKeyExchange.h"
+#elif HAVE_LIBGCRYPT
+#include "LibgcryptDHKeyExchange.h"
+#elif HAVE_OPENSSL
+#include "LibsslDHKeyExchange.h"
+#endif // HAVE_OPENSSL
 
 #endif // D_DH_KEY_EXCHANGE_H
