@@ -32,25 +32,24 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_DL_RETRY_EX_H_
-#define _D_DL_RETRY_EX_H_
+#ifndef D_DL_RETRY_EX_H
+#define D_DL_RETRY_EX_H
 #include "RecoverableException.h"
 
 namespace aria2 {
 
-class DlRetryEx:public RecoverableException {
+class DlRetryEx : public RecoverableException {
 protected:
-  virtual SharedHandle<Exception> copy() const;
+  virtual std::shared_ptr<Exception> copy() const CXX11_OVERRIDE;
+
 public:
   DlRetryEx(const char* file, int line, const std::string& msg);
 
   DlRetryEx(const char* file, int line, const std::string& msg,
             const Exception& cause);
 
-  DlRetryEx(const char* file, int line, const DlRetryEx& e);
-
   DlRetryEx(const char* file, int line, const std::string& msg,
-            downloadresultcode::RESULT code);
+            error_code::Value code);
 };
 
 #define DL_RETRY_EX(arg) DlRetryEx(__FILE__, __LINE__, arg)
@@ -58,4 +57,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_DL_RETRY_EX_H_
+#endif // D_DL_RETRY_EX_H
