@@ -41,20 +41,23 @@
 
 namespace aria2 {
 
-FileAllocationEntry::FileAllocationEntry(RequestGroup* requestGroup, Command* nextCommand):
-  RequestGroupEntry(requestGroup, nextCommand),
-  fileAllocationIterator_(requestGroup->getPieceStorage()->getDiskAdaptor()->fileAllocationIterator())
-{}
+FileAllocationEntry::FileAllocationEntry(RequestGroup* requestGroup,
+                                         std::unique_ptr<Command> nextCommand)
+    : RequestGroupEntry{requestGroup, std::move(nextCommand)},
+      fileAllocationIterator_{requestGroup->getPieceStorage()
+                                  ->getDiskAdaptor()
+                                  ->fileAllocationIterator()}
+{
+}
 
-FileAllocationEntry:: ~FileAllocationEntry()
-{}
+FileAllocationEntry::~FileAllocationEntry() = default;
 
-off_t FileAllocationEntry::getCurrentLength()
+int64_t FileAllocationEntry::getCurrentLength()
 {
   return fileAllocationIterator_->getCurrentLength();
 }
 
-uint64_t FileAllocationEntry::getTotalLength()
+int64_t FileAllocationEntry::getTotalLength()
 {
   return fileAllocationIterator_->getTotalLength();
 }
