@@ -34,28 +34,21 @@
 /* copyright --> */
 #include "GZipEncoder.h"
 
+#include <array>
 #include <cstring>
 
-#include "StringFormat.h"
+#include "fmt.h"
 #include "DlAbortEx.h"
 #include "util.h"
 
 namespace aria2 {
 
-namespace {
-const int OUTBUF_LENGTH = 4096;
-} // namespace
+GZipEncoder::GZipEncoder() : strm_(nullptr) {}
 
-GZipEncoder::GZipEncoder():strm_(0), finished_(false) {}
-
-GZipEncoder::~GZipEncoder()
-{
-  release();
-}
+GZipEncoder::~GZipEncoder() { release(); }
 
 void GZipEncoder::init()
 {
-  finished_ = false;
   release();
   strm_ = new z_stream();
   strm_->zalloc = Z_NULL;
@@ -64,62 +57,47 @@ void GZipEncoder::init()
   strm_->avail_in = 0;
   strm_->next_in = Z_NULL;
 
-  if(Z_OK != deflateInit2
-     (strm_, Z_DEFAULT_COMPRESSION, Z_DEFLATED, 31, 9, Z_DEFAULT_STRATEGY)) {
+  if (Z_OK != deflateInit2(strm_, Z_DEFAULT_COMPRESSION, Z_DEFLATED, 31, 9,
+                           Z_DEFAULT_STRATEGY)) {
     throw DL_ABORT_EX("Initializing z_stream failed.");
   }
 }
 
 void GZipEncoder::release()
 {
-  if(strm_) {
+  if (strm_) {
     deflateEnd(strm_);
     delete strm_;
-    strm_ = 0;
+    strm_ = nullptr;
   }
 }
 
-std::string GZipEncoder::encode
-(const unsigned char* in, size_t length, int flush)
+std::string GZipEncoder::encode(const unsigned char* in, size_t length,
+                                int flush)
 {
-  std::string out;
-
   strm_->avail_in = length;
   strm_->next_in = const_cast<unsigned char*>(in);
-
-  unsigned char outbuf[OUTBUF_LENGTH];
-  while(1) {
-    strm_->avail_out = OUTBUF_LENGTH;
-    strm_->next_out = outbuf;
-
+  std::string out;
+  std::array<unsigned char, 4_k> outbuf;
+  while (1) {
+    strm_->avail_out = outbuf.size();
+    strm_->next_out = outbuf.data();
     int ret = ::deflate(strm_, flush);
-
-    if(ret == Z_STREAM_END) {
-      finished_ = true;
-    } else if(ret != Z_OK) {
-      throw DL_ABORT_EX(StringFormat("libz::deflate() failed. cause:%s",
-                                     strm_->msg).str());
+    if (ret == Z_STREAM_ERROR) {
+      throw DL_ABORT_EX(fmt("libz::deflate() failed. cause:%s", strm_->msg));
     }
-
-    size_t produced = OUTBUF_LENGTH-strm_->avail_out;
-
+    size_t produced = outbuf.size() - strm_->avail_out;
     out.append(&outbuf[0], &outbuf[produced]);
-
-    if(strm_->avail_out > 0) {
+    if (strm_->avail_out > 0) {
       break;
     }
   }
   return out;
 }
 
-bool GZipEncoder::finished()
-{
-  return finished_;
-}
-
 std::string GZipEncoder::str()
 {
-  internalBuf_ += encode(0, 0, Z_FINISH);
+  internalBuf_ += encode(nullptr, 0, Z_FINISH);
   return internalBuf_;
 }
 
@@ -131,8 +109,8 @@ GZipEncoder& GZipEncoder::operator<<(const char* s)
 
 GZipEncoder& GZipEncoder::operator<<(const std::string& s)
 {
-  internalBuf_ += encode
-    (reinterpret_cast<const unsigned char*>(s.data()), s.size());
+  internalBuf_ +=
+      encode(reinterpret_cast<const unsigned char*>(s.data()), s.size());
   return *this;
 }
 
@@ -143,4 +121,10 @@ GZipEncoder& GZipEncoder::operator<<(int64_t i)
   return *this;
 }
 
+GZipEncoder& GZipEncoder::write(const char* s, size_t length)
+{
+  internalBuf_ += encode(reinterpret_cast<const unsigned char*>(s), length);
+  return *this;
+}
+
 } // namespace aria2
