@@ -37,46 +37,76 @@
 
 #include "common.h"
 
+#include <signal.h>
+
 #include <vector>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "DownloadResult.h"
+#include "util.h"
 
 namespace aria2 {
 
 class RequestGroup;
 class Option;
-class StatCalc;
-class OutputFile;
+class UriListParser;
+class DownloadEngine;
 
 class MultiUrlRequestInfo {
 private:
-  std::vector<SharedHandle<RequestGroup> > requestGroups_;
+  std::vector<std::shared_ptr<RequestGroup>> requestGroups_;
 
-  SharedHandle<Option> option_;
+  std::shared_ptr<Option> option_;
 
-  SharedHandle<StatCalc> statCalc_;
+  std::shared_ptr<UriListParser> uriListParser_;
 
-  SharedHandle<OutputFile> summaryOut_;
+  std::unique_ptr<DownloadEngine> e_;
+
+  sigset_t mask_;
+
+  bool useSignalHandler_;
 
   void printMessageForContinue();
+  void setupSignalHandlers();
+  void resetSignalHandlers();
+
 public:
-  MultiUrlRequestInfo
-  (const std::vector<SharedHandle<RequestGroup> >& requestGroups,
-   const SharedHandle<Option>& op,
-   const SharedHandle<StatCalc>& statCalc,
-   const SharedHandle<OutputFile>& summaryOut);
-  
-  virtual ~MultiUrlRequestInfo();
-
-  /**
-   * Returns FINISHED if all downloads have completed, otherwise returns the
-   * last download result.
+  /*
+   * MultiRequestInfo effectively takes ownership of the
+   * requestGroups.
    */
-  error_code::Value execute();
-};
+  MultiUrlRequestInfo(std::vector<std::shared_ptr<RequestGroup>> requestGroups,
+                      const std::shared_ptr<Option>& op,
+                      const std::shared_ptr<UriListParser>& uriListParser);
 
-typedef SharedHandle<MultiUrlRequestInfo> MultiUrlRequestInfoHandle;
+  ~MultiUrlRequestInfo();
+
+  // Returns FINISHED if all downloads have completed, otherwise returns the
+  // last download result.
+  //
+  // This method actually calls prepare() and
+  // getDownloadEngine()->run(true) and getResult().
+  error_code::Value execute();
+
+  // Performs preparations for downloads, including creating
+  // DownloadEngine instance. This function returns 0 if it succeeds,
+  // or -1.
+  int prepare();
+
+  // Performs finalization of download process, including saving
+  // sessions. This function returns last error code in this session,
+  // in particular, this function returns FINISHED if all downloads
+  // have completed.
+  error_code::Value getResult();
+
+  const std::unique_ptr<DownloadEngine>& getDownloadEngine() const;
+
+  // Signal handlers are not prepared if false is given.
+  void setUseSignalHandler(bool useSignalHandler)
+  {
+    useSignalHandler_ = useSignalHandler;
+  }
+};
 
 } // namespace aria2
 
