@@ -36,7 +36,9 @@
 #define D_PEER_ABSTRACT_COMMAND_H
 
 #include "Command.h"
-#include "SharedHandle.h"
+
+#include <memory>
+
 #include "TimerA2.h"
 
 namespace aria2 {
@@ -49,58 +51,54 @@ class SocketCore;
 class PeerAbstractCommand : public Command {
 private:
   Timer checkPoint_;
-  time_t timeout_;
+  std::chrono::seconds timeout_;
   DownloadEngine* e_;
-  SharedHandle<SocketCore> socket_;
-  SharedHandle<Peer> peer_;
+  std::shared_ptr<SocketCore> socket_;
+  std::shared_ptr<Peer> peer_;
 
   bool checkSocketIsReadable_;
   bool checkSocketIsWritable_;
-  SharedHandle<SocketCore> readCheckTarget_;
-  SharedHandle<SocketCore> writeCheckTarget_;
+  std::shared_ptr<SocketCore> readCheckTarget_;
+  std::shared_ptr<SocketCore> writeCheckTarget_;
   bool noCheck_;
-protected:
-  DownloadEngine* getDownloadEngine() const
-  {
-    return e_;
-  }
 
-  const SharedHandle<SocketCore>& getSocket() const
-  {
-    return socket_;
-  }
+protected:
+  DownloadEngine* getDownloadEngine() const { return e_; }
+
+  const std::shared_ptr<SocketCore>& getSocket() const { return socket_; }
 
   void createSocket();
 
-  const SharedHandle<Peer>& getPeer() const
+  const std::shared_ptr<Peer>& getPeer() const { return peer_; }
+
+  void setTimeout(std::chrono::seconds timeout)
   {
-    return peer_;
+    timeout_ = std::move(timeout);
   }
 
-  void setTimeout(time_t timeout) { timeout_ = timeout; }
   virtual bool prepareForNextPeer(time_t wait);
-  virtual void onAbort() {};
+  virtual void onAbort(){};
   // This function is called when DownloadFailureException is caught right after
   // the invocation of onAbort().
-  virtual void onFailure(const Exception& err) {};
+  virtual void onFailure(const Exception& err){};
   virtual bool exitBeforeExecute() = 0;
   virtual bool executeInternal() = 0;
-  void setReadCheckSocket(const SharedHandle<SocketCore>& socket);
-  void setWriteCheckSocket(const SharedHandle<SocketCore>& socket);
+  void setReadCheckSocket(const std::shared_ptr<SocketCore>& socket);
+  void setWriteCheckSocket(const std::shared_ptr<SocketCore>& socket);
   void disableReadCheckSocket();
   void disableWriteCheckSocket();
   void setNoCheck(bool check);
   void updateKeepAlive();
+  void addCommandSelf();
+
 public:
-  PeerAbstractCommand(cuid_t cuid,
-                      const SharedHandle<Peer>& peer,
-                      DownloadEngine* e,
-                      const SharedHandle<SocketCore>& s =
-                      SharedHandle<SocketCore>());
+  PeerAbstractCommand(
+      cuid_t cuid, const std::shared_ptr<Peer>& peer, DownloadEngine* e,
+      const std::shared_ptr<SocketCore>& s = std::shared_ptr<SocketCore>());
 
   virtual ~PeerAbstractCommand();
 
-  virtual bool execute();
+  virtual bool execute() CXX11_OVERRIDE;
 };
 
 } // namespace aria2
