@@ -53,17 +53,14 @@
 
 namespace aria2 {
 
-PeerInitiateConnectionCommand::PeerInitiateConnectionCommand
-(cuid_t cuid,
- RequestGroup* requestGroup,
- const SharedHandle<Peer>& peer,
- DownloadEngine* e,
- const SharedHandle<BtRuntime>& btRuntime,
- bool mseHandshakeEnabled)
-  : PeerAbstractCommand(cuid, peer, e),
-    requestGroup_(requestGroup),
-    btRuntime_(btRuntime),
-    mseHandshakeEnabled_(mseHandshakeEnabled)
+PeerInitiateConnectionCommand::PeerInitiateConnectionCommand(
+    cuid_t cuid, RequestGroup* requestGroup, const std::shared_ptr<Peer>& peer,
+    DownloadEngine* e, const std::shared_ptr<BtRuntime>& btRuntime,
+    bool mseHandshakeEnabled)
+    : PeerAbstractCommand(cuid, peer, e),
+      requestGroup_(requestGroup),
+      btRuntime_(btRuntime),
+      mseHandshakeEnabled_(mseHandshakeEnabled)
 {
   btRuntime_->increaseConnections();
   requestGroup_->increaseNumCommand();
@@ -75,53 +72,51 @@ PeerInitiateConnectionCommand::~PeerInitiateConnectionCommand()
   btRuntime_->decreaseConnections();
 }
 
-bool PeerInitiateConnectionCommand::executeInternal() {
-  A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER,
-                  getCuid(),
-                  getPeer()->getIPAddress().c_str(),
-                  getPeer()->getPort()));
+bool PeerInitiateConnectionCommand::executeInternal()
+{
+  A2_LOG_INFO(fmt(MSG_CONNECTING_TO_SERVER, getCuid(),
+                  getPeer()->getIPAddress().c_str(), getPeer()->getPort()));
   createSocket();
   getSocket()->establishConnection(getPeer()->getIPAddress(),
                                    getPeer()->getPort(), false);
-  if(mseHandshakeEnabled_) {
-    InitiatorMSEHandshakeCommand* c =
-      new InitiatorMSEHandshakeCommand(getCuid(), requestGroup_, getPeer(),
-                                       getDownloadEngine(),
-                                       btRuntime_, getSocket());
+  getSocket()->applyIpDscp();
+  if (mseHandshakeEnabled_) {
+    auto c = make_unique<InitiatorMSEHandshakeCommand>(
+        getCuid(), requestGroup_, getPeer(), getDownloadEngine(), btRuntime_,
+        getSocket());
     c->setPeerStorage(peerStorage_);
     c->setPieceStorage(pieceStorage_);
-    getDownloadEngine()->addCommand(c);
-  } else {
-    PeerInteractionCommand* command =
-      new PeerInteractionCommand
-      (getCuid(), requestGroup_, getPeer(), getDownloadEngine(),
-       btRuntime_, pieceStorage_, peerStorage_,
-       getSocket(), PeerInteractionCommand::INITIATOR_SEND_HANDSHAKE);
-    getDownloadEngine()->addCommand(command);
+    getDownloadEngine()->addCommand(std::move(c));
+  }
+  else {
+    getDownloadEngine()->addCommand(make_unique<PeerInteractionCommand>(
+        getCuid(), requestGroup_, getPeer(), getDownloadEngine(), btRuntime_,
+        pieceStorage_, peerStorage_, getSocket(),
+        PeerInteractionCommand::INITIATOR_SEND_HANDSHAKE));
   }
   return true;
 }
 
 // TODO this method removed when PeerBalancerCommand is implemented
-bool PeerInitiateConnectionCommand::prepareForNextPeer(time_t wait) {
-  if(peerStorage_->isPeerAvailable() && btRuntime_->lessThanEqMinPeers()) {
+bool PeerInitiateConnectionCommand::prepareForNextPeer(time_t wait)
+{
+  if (peerStorage_->isPeerAvailable() && btRuntime_->lessThanEqMinPeers()) {
     cuid_t ncuid = getDownloadEngine()->newCUID();
-    SharedHandle<Peer> peer = peerStorage_->checkoutPeer(ncuid);
+    std::shared_ptr<Peer> peer = peerStorage_->checkoutPeer(ncuid);
     // sanity check
-    if(peer) {
-      PeerInitiateConnectionCommand* command;
-      command = new PeerInitiateConnectionCommand(ncuid, requestGroup_, peer,
-                                                  getDownloadEngine(),
-                                                  btRuntime_);
+    if (peer) {
+      auto command = make_unique<PeerInitiateConnectionCommand>(
+          ncuid, requestGroup_, peer, getDownloadEngine(), btRuntime_);
       command->setPeerStorage(peerStorage_);
       command->setPieceStorage(pieceStorage_);
-      getDownloadEngine()->addCommand(command);
+      getDownloadEngine()->addCommand(std::move(command));
     }
   }
   return true;
 }
 
-void PeerInitiateConnectionCommand::onAbort() {
+void PeerInitiateConnectionCommand::onAbort()
+{
   peerStorage_->returnPeer(getPeer());
 }
 
@@ -130,14 +125,14 @@ bool PeerInitiateConnectionCommand::exitBeforeExecute()
   return btRuntime_->isHalt();
 }
 
-void PeerInitiateConnectionCommand::setPeerStorage
-(const SharedHandle<PeerStorage>& peerStorage)
+void PeerInitiateConnectionCommand::setPeerStorage(
+    const std::shared_ptr<PeerStorage>& peerStorage)
 {
   peerStorage_ = peerStorage;
 }
 
-void PeerInitiateConnectionCommand::setPieceStorage
-(const SharedHandle<PieceStorage>& pieceStorage)
+void PeerInitiateConnectionCommand::setPieceStorage(
+    const std::shared_ptr<PieceStorage>& pieceStorage)
 {
   pieceStorage_ = pieceStorage;
 }
