@@ -38,8 +38,8 @@
 #include "common.h"
 
 #include <string>
+#include <memory>
 
-#include "SharedHandle.h"
 #include "ValueBase.h"
 
 namespace aria2 {
@@ -64,38 +64,43 @@ struct RpcResponse;
 // to RpcMethodFactory.
 class RpcMethod {
 private:
-  SharedHandle<OptionParser> optionParser_;
+  std::shared_ptr<OptionParser> optionParser_;
+
 protected:
   // Subclass must implement this function to fulfil RpcRequest req.
   // The return value of this method is used as a return value of RPC
   // request.
-  virtual SharedHandle<ValueBase> process
-  (const RpcRequest& req, DownloadEngine* e) = 0;
+  virtual std::unique_ptr<ValueBase> process(const RpcRequest& req,
+                                             DownloadEngine* e) = 0;
 
   void gatherRequestOption(Option* option, const Dict* optionsDict);
 
-  void gatherChangeableOption(Option* option, const Dict* optionDict);
+  void gatherChangeableOption(Option* option, Option* pendingOption,
+                              const Dict* optionDict);
 
-  void gatherChangeableOptionForReserved
-  (Option* option, const Dict* optionsDict);
+  void gatherChangeableOptionForReserved(Option* option,
+                                         const Dict* optionsDict);
 
   void gatherChangeableGlobalOption(Option* option, const Dict* optionDict);
 
-  SharedHandle<ValueBase> createErrorResponse
-  (const Exception& e, const RpcRequest& req);
+  std::unique_ptr<ValueBase> createErrorResponse(const Exception& e,
+                                                 const RpcRequest& req);
 
-  const SharedHandle<OptionParser>& getOptionParser() const
+  const std::shared_ptr<OptionParser>& getOptionParser() const
   {
     return optionParser_;
   }
+
 public:
   RpcMethod();
 
   virtual ~RpcMethod();
 
+  virtual void authorize(RpcRequest& req, DownloadEngine* e);
+
   // Do work to fulfill RpcRequest req and returns its result as
   // RpcResponse. This method delegates to process() method.
-  RpcResponse execute(const RpcRequest& req, DownloadEngine* e);
+  virtual RpcResponse execute(RpcRequest req, DownloadEngine* e);
 };
 
 } // namespace rpc
