@@ -35,6 +35,7 @@
 #ifndef D_UNKNOWN_LENGTH_PIECE_STORAGE_H
 #define D_UNKNOWN_LENGTH_PIECE_STORAGE_H
 
+#include "FatalException.h"
 #include "PieceStorage.h"
 
 namespace aria2 {
@@ -135,7 +136,7 @@ public:
   virtual std::shared_ptr<Piece> getPiece(size_t index) CXX11_OVERRIDE;
 
   /**
-   * Tells that the download of the specfied piece completes.
+   * Tells that the download of the specified piece completes.
    */
   virtual void
   completePiece(const std::shared_ptr<Piece>& piece) CXX11_OVERRIDE;
@@ -236,6 +237,7 @@ public:
   getAdvertisedPieceIndexes(std::vector<size_t>& indexes, cuid_t myCuid,
                             uint64_t lastHaveIndex) CXX11_OVERRIDE
   {
+    throw FATAL_EXCEPTION("Not Implemented!");
   }
 
   virtual void removeAdvertisedPiece(const Timer& expiry) CXX11_OVERRIDE {}
