@@ -24,7 +24,7 @@
 
 namespace aria2 {
 
-class DHTMessageFactoryImplTest:public CppUnit::TestFixture {
+class DHTMessageFactoryImplTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(DHTMessageFactoryImplTest);
   CPPUNIT_TEST(testCreatePingMessage);
@@ -39,12 +39,16 @@ class DHTMessageFactoryImplTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testCreateAnnouncePeerReplyMessage);
   CPPUNIT_TEST(testReceivedErrorMessage);
   CPPUNIT_TEST_SUITE_END();
+
 public:
-  SharedHandle<DHTMessageFactoryImpl> factory;
+  std::unique_ptr<DHTMessageFactoryImpl> factory;
 
-  SharedHandle<DHTRoutingTable> routingTable;
+  std::unique_ptr<DHTRoutingTable> routingTable;
 
-  SharedHandle<DHTNode> localNode;
+  std::shared_ptr<DHTNode> localNode;
+
+  std::unique_ptr<DHTNode> remoteNode_;
+  std::unique_ptr<DHTNode> remoteNode6_;
 
   unsigned char transactionID[DHT_TRANSACTION_ID_LENGTH];
 
@@ -52,13 +56,21 @@ public:
 
   void setUp()
   {
-    localNode.reset(new DHTNode());
-    factory.reset(new DHTMessageFactoryImpl(AF_INET));
+    localNode = std::make_shared<DHTNode>();
+    factory = make_unique<DHTMessageFactoryImpl>(AF_INET);
     factory->setLocalNode(localNode);
     memset(transactionID, 0xff, DHT_TRANSACTION_ID_LENGTH);
     memset(remoteNodeID, 0x0f, DHT_ID_LENGTH);
-    routingTable.reset(new DHTRoutingTable(localNode));
+    routingTable = make_unique<DHTRoutingTable>(localNode);
     factory->setRoutingTable(routingTable.get());
+
+    remoteNode_ = make_unique<DHTNode>(remoteNodeID);
+    remoteNode_->setIPAddress("192.168.0.1");
+    remoteNode_->setPort(6881);
+
+    remoteNode6_ = make_unique<DHTNode>(remoteNodeID);
+    remoteNode6_->setIPAddress("2001::2001");
+    remoteNode6_->setPort(6881);
   }
 
   void tearDown() {}
@@ -76,7 +88,6 @@ public:
   void testReceivedErrorMessage();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(DHTMessageFactoryImplTest);
 
 void DHTMessageFactoryImplTest::testCreatePingMessage()
@@ -85,19 +96,15 @@ void DHTMessageFactoryImplTest::testCreatePingMessage()
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "q");
   dict.put("q", "ping");
-  SharedHandle<Dict> aDict = Dict::g();
+  auto aDict = Dict::g();
   aDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
-  dict.put("a", aDict);
-  
-  SharedHandle<DHTPingMessage> m
-    (dynamic_pointer_cast<DHTPingMessage>
-     (factory->createQueryMessage(&dict, "192.168.0.1", 6881)));
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
+  dict.put("a", std::move(aDict));
+
+  auto r = factory->createQueryMessage(&dict, "192.168.0.1", 6881);
+  auto m = dynamic_cast<DHTPingMessage*>(r.get());
 
   CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-  CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+  CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                        util::toHex(m->getTransactionID()));
 }
@@ -107,22 +114,16 @@ void DHTMessageFactoryImplTest::testCreatePingReplyMessage()
   Dict dict;
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "r");
-  SharedHandle<Dict> rDict = Dict::g();
+  auto rDict = Dict::g();
   rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
-  dict.put("r", rDict);
+  dict.put("r", std::move(rDict));
 
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
-  
-  SharedHandle<DHTPingReplyMessage> m
-    (dynamic_pointer_cast<DHTPingReplyMessage>
-     (factory->createResponseMessage("ping", &dict,
-                                     remoteNode->getIPAddress(),
-                                     remoteNode->getPort())));
+  auto r = factory->createResponseMessage(
+      "ping", &dict, remoteNode_->getIPAddress(), remoteNode_->getPort());
+  auto m = dynamic_cast<DHTPingReplyMessage*>(r.get());
 
   CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-  CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+  CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                        util::toHex(m->getTransactionID()));
 }
@@ -133,22 +134,18 @@ void DHTMessageFactoryImplTest::testCreateFindNodeMessage()
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "q");
   dict.put("q", "find_node");
-  SharedHandle<Dict> aDict = Dict::g();
+  auto aDict = Dict::g();
   aDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
   unsigned char targetNodeID[DHT_ID_LENGTH];
   memset(targetNodeID, 0x11, DHT_ID_LENGTH);
   aDict->put("target", String::g(targetNodeID, DHT_ID_LENGTH));
-  dict.put("a", aDict);
-  
-  SharedHandle<DHTFindNodeMessage> m
-    (dynamic_pointer_cast<DHTFindNodeMessage>
-     (factory->createQueryMessage(&dict, "192.168.0.1", 6881)));
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
+  dict.put("a", std::move(aDict));
+
+  auto r = factory->createQueryMessage(&dict, "192.168.0.1", 6881);
+  auto m = dynamic_cast<DHTFindNodeMessage*>(r.get());
 
   CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-  CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+  CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                        util::toHex(m->getTransactionID()));
   CPPUNIT_ASSERT_EQUAL(util::toHex(targetNodeID, DHT_ID_LENGTH),
@@ -161,97 +158,87 @@ void DHTMessageFactoryImplTest::testCreateFindNodeReplyMessage()
     Dict dict;
     dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
     dict.put("y", "r");
-    SharedHandle<Dict> rDict = Dict::g();
+    auto rDict = Dict::g();
     rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
     std::string compactNodeInfo;
-    SharedHandle<DHTNode> nodes[8];
-    for(size_t i = 0; i < DHTBucket::K; ++i) {
-      nodes[i].reset(new DHTNode());
-      nodes[i]->setIPAddress("192.168.0."+util::uitos(i+1));
-      nodes[i]->setPort(6881+i);
+    std::shared_ptr<DHTNode> nodes[8];
+    for (size_t i = 0; i < DHTBucket::K; ++i) {
+      nodes[i] = std::make_shared<DHTNode>();
+      nodes[i]->setIPAddress("192.168.0." + util::uitos(i + 1));
+      nodes[i]->setPort(6881 + i);
 
       unsigned char buf[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV4,
-         bittorrent::packcompact
-         (buf, nodes[i]->getIPAddress(), nodes[i]->getPort()));
-      compactNodeInfo +=
-        std::string(&nodes[i]->getID()[0], &nodes[i]->getID()[DHT_ID_LENGTH])+
-        std::string(&buf[0], &buf[COMPACT_LEN_IPV4]);
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV4, bittorrent::packcompact(
+                                                 buf, nodes[i]->getIPAddress(),
+                                                 nodes[i]->getPort()));
+      compactNodeInfo += std::string(&nodes[i]->getID()[0],
+                                     &nodes[i]->getID()[DHT_ID_LENGTH]) +
+                         std::string(&buf[0], &buf[COMPACT_LEN_IPV4]);
     }
     rDict->put("nodes", compactNodeInfo);
-    dict.put("r", rDict);
+    dict.put("r", std::move(rDict));
 
-    SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-    remoteNode->setIPAddress("192.168.0.1");
-    remoteNode->setPort(6881);
-  
-    SharedHandle<DHTFindNodeReplyMessage> m
-      (dynamic_pointer_cast<DHTFindNodeReplyMessage>
-       (factory->createResponseMessage("find_node", &dict,
-                                       remoteNode->getIPAddress(),
-                                       remoteNode->getPort())));
+    auto r = factory->createResponseMessage("find_node", &dict,
+                                            remoteNode_->getIPAddress(),
+                                            remoteNode_->getPort());
+    auto m = dynamic_cast<DHTFindNodeReplyMessage*>(r.get());
 
     CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-    CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+    CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
     CPPUNIT_ASSERT_EQUAL((size_t)DHTBucket::K, m->getClosestKNodes().size());
     CPPUNIT_ASSERT(*nodes[0] == *m->getClosestKNodes()[0]);
     CPPUNIT_ASSERT(*nodes[7] == *m->getClosestKNodes()[7]);
     CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                          util::toHex(m->getTransactionID()));
-  } catch(Exception& e) {
+  }
+  catch (Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
 }
 
 void DHTMessageFactoryImplTest::testCreateFindNodeReplyMessage6()
 {
-  factory.reset(new DHTMessageFactoryImpl(AF_INET6));
+  factory = make_unique<DHTMessageFactoryImpl>(AF_INET6);
   factory->setLocalNode(localNode);
   factory->setRoutingTable(routingTable.get());
   try {
     Dict dict;
     dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
     dict.put("y", "r");
-    SharedHandle<Dict> rDict = Dict::g();
+    auto rDict = Dict::g();
     rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
     std::string compactNodeInfo;
-    SharedHandle<DHTNode> nodes[8];
-    for(size_t i = 0; i < DHTBucket::K; ++i) {
-      nodes[i].reset(new DHTNode());
-      nodes[i]->setIPAddress("2001::000"+util::uitos(i+1));
-      nodes[i]->setPort(6881+i);
+    std::shared_ptr<DHTNode> nodes[8];
+    for (size_t i = 0; i < DHTBucket::K; ++i) {
+      nodes[i] = std::make_shared<DHTNode>();
+      nodes[i]->setIPAddress("2001::000" + util::uitos(i + 1));
+      nodes[i]->setPort(6881 + i);
 
       unsigned char buf[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV6,
-         bittorrent::packcompact
-         (buf, nodes[i]->getIPAddress(), nodes[i]->getPort()));
-      compactNodeInfo +=
-        std::string(&nodes[i]->getID()[0], &nodes[i]->getID()[DHT_ID_LENGTH])+
-        std::string(&buf[0], &buf[COMPACT_LEN_IPV6]);
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV6, bittorrent::packcompact(
+                                                 buf, nodes[i]->getIPAddress(),
+                                                 nodes[i]->getPort()));
+      compactNodeInfo += std::string(&nodes[i]->getID()[0],
+                                     &nodes[i]->getID()[DHT_ID_LENGTH]) +
+                         std::string(&buf[0], &buf[COMPACT_LEN_IPV6]);
     }
     rDict->put("nodes6", compactNodeInfo);
-    dict.put("r", rDict);
+    dict.put("r", std::move(rDict));
 
-    SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-    remoteNode->setIPAddress("2001::2001");
-    remoteNode->setPort(6881);
-  
-    SharedHandle<DHTFindNodeReplyMessage> m
-      (dynamic_pointer_cast<DHTFindNodeReplyMessage>
-       (factory->createResponseMessage("find_node", &dict,
-                                       remoteNode->getIPAddress(),
-                                       remoteNode->getPort())));
+    auto r = factory->createResponseMessage("find_node", &dict,
+                                            remoteNode_->getIPAddress(),
+                                            remoteNode_->getPort());
+    auto m = dynamic_cast<DHTFindNodeReplyMessage*>(r.get());
 
     CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-    CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+    CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
     CPPUNIT_ASSERT_EQUAL((size_t)DHTBucket::K, m->getClosestKNodes().size());
     CPPUNIT_ASSERT(*nodes[0] == *m->getClosestKNodes()[0]);
     CPPUNIT_ASSERT(*nodes[7] == *m->getClosestKNodes()[7]);
     CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                          util::toHex(m->getTransactionID()));
-  } catch(Exception& e) {
+  }
+  catch (Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
 }
@@ -262,22 +249,18 @@ void DHTMessageFactoryImplTest::testCreateGetPeersMessage()
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "q");
   dict.put("q", "get_peers");
-  SharedHandle<Dict> aDict = Dict::g();
+  auto aDict = Dict::g();
   aDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
   unsigned char infoHash[DHT_ID_LENGTH];
   memset(infoHash, 0x11, DHT_ID_LENGTH);
   aDict->put("info_hash", String::g(infoHash, DHT_ID_LENGTH));
-  dict.put("a", aDict);
-  
-  SharedHandle<DHTGetPeersMessage> m
-    (dynamic_pointer_cast<DHTGetPeersMessage>
-     (factory->createQueryMessage(&dict, "192.168.0.1", 6881)));
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
+  dict.put("a", std::move(aDict));
+
+  auto r = factory->createQueryMessage(&dict, "192.168.0.1", 6881);
+  auto m = dynamic_cast<DHTGetPeersMessage*>(r.get());
 
   CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-  CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+  CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                        util::toHex(m->getTransactionID()));
   CPPUNIT_ASSERT_EQUAL(util::toHex(infoHash, DHT_ID_LENGTH),
@@ -290,137 +273,131 @@ void DHTMessageFactoryImplTest::testCreateGetPeersReplyMessage()
     Dict dict;
     dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
     dict.put("y", "r");
-    SharedHandle<Dict> rDict = Dict::g();
+    auto rDict = Dict::g();
     rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
     std::string compactNodeInfo;
-    SharedHandle<DHTNode> nodes[8];
-    for(size_t i = 0; i < DHTBucket::K; ++i) {
-      nodes[i].reset(new DHTNode());
-      nodes[i]->setIPAddress("192.168.0."+util::uitos(i+1));
-      nodes[i]->setPort(6881+i);
+    std::shared_ptr<DHTNode> nodes[8];
+    for (size_t i = 0; i < DHTBucket::K; ++i) {
+      nodes[i] = std::make_shared<DHTNode>();
+      nodes[i]->setIPAddress("192.168.0." + util::uitos(i + 1));
+      nodes[i]->setPort(6881 + i);
 
       unsigned char buf[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV4,
-         bittorrent::packcompact
-         (buf, nodes[i]->getIPAddress(), nodes[i]->getPort()));
-      compactNodeInfo +=
-        std::string(&nodes[i]->getID()[0], &nodes[i]->getID()[DHT_ID_LENGTH])+
-        std::string(&buf[0], &buf[COMPACT_LEN_IPV4]);
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV4, bittorrent::packcompact(
+                                                 buf, nodes[i]->getIPAddress(),
+                                                 nodes[i]->getPort()));
+      compactNodeInfo += std::string(&nodes[i]->getID()[0],
+                                     &nodes[i]->getID()[DHT_ID_LENGTH]) +
+                         std::string(&buf[0], &buf[COMPACT_LEN_IPV4]);
     }
     rDict->put("nodes", compactNodeInfo);
 
-    std::deque<SharedHandle<Peer> > peers;
-    SharedHandle<List> valuesList = List::g();
-    for(size_t i = 0; i < 4; ++i) {
-      SharedHandle<Peer> peer(new Peer("192.168.0."+util::uitos(i+1), 6881+i));
+    std::deque<std::shared_ptr<Peer>> peers;
+    auto valuesList = List::g();
+    for (size_t i = 0; i < 4; ++i) {
+      auto peer =
+          std::make_shared<Peer>("192.168.0." + util::uitos(i + 1), 6881 + i);
       unsigned char buffer[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV4,
-         bittorrent::packcompact
-         (buffer, peer->getIPAddress(), peer->getPort()));
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV4,
+                           bittorrent::packcompact(buffer, peer->getIPAddress(),
+                                                   peer->getPort()));
       valuesList->append(String::g(buffer, COMPACT_LEN_IPV4));
       peers.push_back(peer);
     }
-    rDict->put("values", valuesList);
-
+    rDict->put("values", std::move(valuesList));
     rDict->put("token", "token");
-    dict.put("r", rDict);
+    dict.put("r", std::move(rDict));
 
-    SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-    remoteNode->setIPAddress("192.168.0.1");
-    remoteNode->setPort(6881);
-  
-    SharedHandle<DHTGetPeersReplyMessage> m
-      (dynamic_pointer_cast<DHTGetPeersReplyMessage>
-       (factory->createResponseMessage("get_peers", &dict,
-                                       remoteNode->getIPAddress(),
-                                       remoteNode->getPort())));
+    auto r = factory->createResponseMessage("get_peers", &dict,
+                                            remoteNode_->getIPAddress(),
+                                            remoteNode_->getPort());
+    auto m = dynamic_cast<DHTGetPeersReplyMessage*>(r.get());
 
     CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-    CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+    CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
     CPPUNIT_ASSERT_EQUAL(std::string("token"), m->getToken());
     CPPUNIT_ASSERT_EQUAL((size_t)DHTBucket::K, m->getClosestKNodes().size());
     CPPUNIT_ASSERT(*nodes[0] == *m->getClosestKNodes()[0]);
     CPPUNIT_ASSERT(*nodes[7] == *m->getClosestKNodes()[7]);
     CPPUNIT_ASSERT_EQUAL((size_t)4, m->getValues().size());
-    CPPUNIT_ASSERT(*peers[0] == *m->getValues()[0]);
-    CPPUNIT_ASSERT(*peers[3] == *m->getValues()[3]);
+    for (int i = 0; i < 4; ++i) {
+      CPPUNIT_ASSERT_EQUAL(peers[i]->getIPAddress(),
+                           m->getValues()[i]->getIPAddress());
+      CPPUNIT_ASSERT_EQUAL(peers[i]->getPort(), m->getValues()[i]->getPort());
+    }
     CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                          util::toHex(m->getTransactionID()));
-  } catch(Exception& e) {
+  }
+  catch (Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
 }
 
 void DHTMessageFactoryImplTest::testCreateGetPeersReplyMessage6()
 {
-  factory.reset(new DHTMessageFactoryImpl(AF_INET6));
+  factory = make_unique<DHTMessageFactoryImpl>(AF_INET6);
   factory->setLocalNode(localNode);
   factory->setRoutingTable(routingTable.get());
   try {
     Dict dict;
     dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
     dict.put("y", "r");
-    SharedHandle<Dict> rDict = Dict::g();
+    auto rDict = Dict::g();
     rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
     std::string compactNodeInfo;
-    SharedHandle<DHTNode> nodes[8];
-    for(size_t i = 0; i < DHTBucket::K; ++i) {
-      nodes[i].reset(new DHTNode());
-      nodes[i]->setIPAddress("2001::000"+util::uitos(i+1));
-      nodes[i]->setPort(6881+i);
+    std::shared_ptr<DHTNode> nodes[8];
+    for (size_t i = 0; i < DHTBucket::K; ++i) {
+      nodes[i] = std::make_shared<DHTNode>();
+      nodes[i]->setIPAddress("2001::000" + util::uitos(i + 1));
+      nodes[i]->setPort(6881 + i);
 
       unsigned char buf[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV6,
-         bittorrent::packcompact
-         (buf, nodes[i]->getIPAddress(), nodes[i]->getPort()));
-      compactNodeInfo +=
-        std::string(&nodes[i]->getID()[0], &nodes[i]->getID()[DHT_ID_LENGTH])+
-        std::string(&buf[0], &buf[COMPACT_LEN_IPV6]);
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV6, bittorrent::packcompact(
+                                                 buf, nodes[i]->getIPAddress(),
+                                                 nodes[i]->getPort()));
+      compactNodeInfo += std::string(&nodes[i]->getID()[0],
+                                     &nodes[i]->getID()[DHT_ID_LENGTH]) +
+                         std::string(&buf[0], &buf[COMPACT_LEN_IPV6]);
     }
     rDict->put("nodes6", compactNodeInfo);
 
-    std::deque<SharedHandle<Peer> > peers;
-    SharedHandle<List> valuesList = List::g();
-    for(size_t i = 0; i < 4; ++i) {
-      SharedHandle<Peer> peer(new Peer("2001::100"+util::uitos(i+1), 6881+i));
+    std::deque<std::shared_ptr<Peer>> peers;
+    auto valuesList = List::g();
+    for (size_t i = 0; i < 4; ++i) {
+      auto peer =
+          std::make_shared<Peer>("2001::100" + util::uitos(i + 1), 6881 + i);
       unsigned char buffer[COMPACT_LEN_IPV6];
-      CPPUNIT_ASSERT_EQUAL
-        (COMPACT_LEN_IPV6,
-         bittorrent::packcompact
-         (buffer, peer->getIPAddress(), peer->getPort()));
+      CPPUNIT_ASSERT_EQUAL(COMPACT_LEN_IPV6,
+                           bittorrent::packcompact(buffer, peer->getIPAddress(),
+                                                   peer->getPort()));
       valuesList->append(String::g(buffer, COMPACT_LEN_IPV6));
       peers.push_back(peer);
     }
-    rDict->put("values", valuesList);
-
+    rDict->put("values", std::move(valuesList));
     rDict->put("token", "token");
-    dict.put("r", rDict);
+    dict.put("r", std::move(rDict));
 
-    SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-    remoteNode->setIPAddress("2001::2001");
-    remoteNode->setPort(6881);
-  
-    SharedHandle<DHTGetPeersReplyMessage> m
-      (dynamic_pointer_cast<DHTGetPeersReplyMessage>
-       (factory->createResponseMessage("get_peers", &dict,
-                                       remoteNode->getIPAddress(),
-                                       remoteNode->getPort())));
+    auto r = factory->createResponseMessage("get_peers", &dict,
+                                            remoteNode_->getIPAddress(),
+                                            remoteNode_->getPort());
+    auto m = dynamic_cast<DHTGetPeersReplyMessage*>(r.get());
 
     CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-    CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+    CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
     CPPUNIT_ASSERT_EQUAL(std::string("token"), m->getToken());
     CPPUNIT_ASSERT_EQUAL((size_t)DHTBucket::K, m->getClosestKNodes().size());
     CPPUNIT_ASSERT(*nodes[0] == *m->getClosestKNodes()[0]);
     CPPUNIT_ASSERT(*nodes[7] == *m->getClosestKNodes()[7]);
     CPPUNIT_ASSERT_EQUAL((size_t)4, m->getValues().size());
-    CPPUNIT_ASSERT(*peers[0] == *m->getValues()[0]);
-    CPPUNIT_ASSERT(*peers[3] == *m->getValues()[3]);
+    for (int i = 0; i < 4; ++i) {
+      CPPUNIT_ASSERT_EQUAL(peers[i]->getIPAddress(),
+                           m->getValues()[i]->getIPAddress());
+      CPPUNIT_ASSERT_EQUAL(peers[i]->getPort(), m->getValues()[i]->getPort());
+    }
     CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                          util::toHex(m->getTransactionID()));
-  } catch(Exception& e) {
+  }
+  catch (Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
 }
@@ -432,7 +409,7 @@ void DHTMessageFactoryImplTest::testCreateAnnouncePeerMessage()
     dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
     dict.put("y", "q");
     dict.put("q", "announce_peer");
-    SharedHandle<Dict> aDict = Dict::g();
+    auto aDict = Dict::g();
     aDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
     unsigned char infoHash[DHT_ID_LENGTH];
     memset(infoHash, 0x11, DHT_ID_LENGTH);
@@ -441,24 +418,23 @@ void DHTMessageFactoryImplTest::testCreateAnnouncePeerMessage()
     uint16_t port = 6881;
     aDict->put("port", Integer::g(port));
     aDict->put("token", token);
-    dict.put("a", aDict);
-  
-    SharedHandle<DHTAnnouncePeerMessage> m
-      (dynamic_pointer_cast<DHTAnnouncePeerMessage>
-       (factory->createQueryMessage(&dict, "192.168.0.1", 6882)));
-    SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-    remoteNode->setIPAddress("192.168.0.1");
-    remoteNode->setPort(6882);
+    dict.put("a", std::move(aDict));
+
+    remoteNode_->setPort(6882);
+
+    auto r = factory->createQueryMessage(&dict, "192.168.0.1", 6882);
+    auto m = dynamic_cast<DHTAnnouncePeerMessage*>(r.get());
 
     CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-    CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+    CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
     CPPUNIT_ASSERT_EQUAL(token, m->getToken());
     CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                          util::toHex(m->getTransactionID()));
     CPPUNIT_ASSERT_EQUAL(util::toHex(infoHash, DHT_ID_LENGTH),
                          util::toHex(m->getInfoHash(), DHT_ID_LENGTH));
     CPPUNIT_ASSERT_EQUAL(port, m->getTCPPort());
-  } catch(Exception& e) {
+  }
+  catch (Exception& e) {
     CPPUNIT_FAIL(e.stackTrace());
   }
 }
@@ -468,22 +444,17 @@ void DHTMessageFactoryImplTest::testCreateAnnouncePeerReplyMessage()
   Dict dict;
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "r");
-  SharedHandle<Dict> rDict = Dict::g();
+  auto rDict = Dict::g();
   rDict->put("id", String::g(remoteNodeID, DHT_ID_LENGTH));
-  dict.put("r", rDict);
+  dict.put("r", std::move(rDict));
 
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
-  
-  SharedHandle<DHTAnnouncePeerReplyMessage> m
-    (dynamic_pointer_cast<DHTAnnouncePeerReplyMessage>
-     (factory->createResponseMessage("announce_peer", &dict,
-                                     remoteNode->getIPAddress(),
-                                     remoteNode->getPort())));
+  auto r = factory->createResponseMessage("announce_peer", &dict,
+                                          remoteNode_->getIPAddress(),
+                                          remoteNode_->getPort());
+  auto m = dynamic_cast<DHTAnnouncePeerReplyMessage*>(r.get());
 
   CPPUNIT_ASSERT(*localNode == *m->getLocalNode());
-  CPPUNIT_ASSERT(*remoteNode == *m->getRemoteNode());
+  CPPUNIT_ASSERT(*remoteNode_ == *m->getRemoteNode());
   CPPUNIT_ASSERT_EQUAL(util::toHex(transactionID, DHT_TRANSACTION_ID_LENGTH),
                        util::toHex(m->getTransactionID()));
 }
@@ -493,21 +464,18 @@ void DHTMessageFactoryImplTest::testReceivedErrorMessage()
   Dict dict;
   dict.put("t", String::g(transactionID, DHT_TRANSACTION_ID_LENGTH));
   dict.put("y", "e");
-  SharedHandle<List> list = List::g();
+  auto list = List::g();
   list->append(Integer::g(404));
   list->append("Not found");
-  dict.put("e", list);
-
-  SharedHandle<DHTNode> remoteNode(new DHTNode(remoteNodeID));
-  remoteNode->setIPAddress("192.168.0.1");
-  remoteNode->setPort(6881);
+  dict.put("e", std::move(list));
 
   try {
     factory->createResponseMessage("announce_peer", &dict,
-                                   remoteNode->getIPAddress(),
-                                   remoteNode->getPort());
+                                   remoteNode_->getIPAddress(),
+                                   remoteNode_->getPort());
     CPPUNIT_FAIL("exception must be thrown.");
-  } catch(RecoverableException& e) {
+  }
+  catch (RecoverableException& e) {
     std::cerr << e.stackTrace() << std::endl;
   }
 }
