@@ -14,14 +14,14 @@
 #include "FileEntry.h"
 #include "array_fun.h"
 #ifdef ENABLE_BITTORRENT
-# include "MockPeerStorage.h"
-# include "BtRuntime.h"
-# include "bittorrent_helper.h"
+#include "MockPeerStorage.h"
+#include "BtRuntime.h"
+#include "bittorrent_helper.h"
 #endif // ENABLE_BITTORRENT
 
 namespace aria2 {
 
-class DefaultBtProgressInfoFileTest:public CppUnit::TestFixture {
+class DefaultBtProgressInfoFileTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(DefaultBtProgressInfoFileTest);
 #ifdef ENABLE_BITTORRENT
@@ -39,20 +39,21 @@ class DefaultBtProgressInfoFileTest:public CppUnit::TestFixture {
   CPPUNIT_TEST(testLoad_nonBt_pieceLengthShorter);
   CPPUNIT_TEST(testUpdateFilename);
   CPPUNIT_TEST_SUITE_END();
+
 private:
-
 #ifdef ENABLE_BITTORRENT
-  SharedHandle<DownloadContext> dctx_;
+  std::shared_ptr<DownloadContext> dctx_;
 
-  SharedHandle<MockPeerStorage> peerStorage_;
+  std::shared_ptr<MockPeerStorage> peerStorage_;
 
-  SharedHandle<BtRuntime> btRuntime_;
+  std::shared_ptr<BtRuntime> btRuntime_;
 #endif // ENABLE_BITTORRENT
 
-  SharedHandle<MockPieceStorage> pieceStorage_;
-  SharedHandle<Option> option_;
-  SharedHandle<BitfieldMan> bitfield_;
-public:   
+  std::shared_ptr<MockPieceStorage> pieceStorage_;
+  std::shared_ptr<Option> option_;
+  std::shared_ptr<BitfieldMan> bitfield_;
+
+public:
   void initializeMembers(int32_t pieceLength, int64_t totalLength)
   {
     option_.reset(new Option());
@@ -65,18 +66,20 @@ public:
 
 #ifdef ENABLE_BITTORRENT
     static unsigned char infoHash[] = {
-      0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88, 0x99, 0xaa,
-      0xbb, 0xcc, 0xdd, 0xee, 0xff, 0x00, 0xff, 0xff, 0xff, 0xff,
+        0x11, 0x22, 0x33, 0x44, 0x55, 0x66, 0x77, 0x88, 0x99, 0xaa,
+        0xbb, 0xcc, 0xdd, 0xee, 0xff, 0x00, 0xff, 0xff, 0xff, 0xff,
     };
-  
+
     dctx_.reset(new DownloadContext());
-    SharedHandle<TorrentAttribute> torrentAttrs(new TorrentAttribute());
-    torrentAttrs->infoHash = std::string(vbegin(infoHash), vend(infoHash));
-    dctx_->setAttribute(bittorrent::BITTORRENT, torrentAttrs);
-    const SharedHandle<FileEntry> fileEntries[] = {
-      SharedHandle<FileEntry>(new FileEntry("/path/to/file",totalLength,0))
-    };
-    dctx_->setFileEntries(vbegin(fileEntries), vend(fileEntries));
+    {
+      auto torrentAttrs = make_unique<TorrentAttribute>();
+      torrentAttrs->infoHash.assign(std::begin(infoHash), std::end(infoHash));
+      dctx_->setAttribute(CTX_ATTR_BT, std::move(torrentAttrs));
+    }
+    const std::shared_ptr<FileEntry> fileEntries[] = {
+        std::shared_ptr<FileEntry>(
+            new FileEntry("/path/to/file", totalLength, 0))};
+    dctx_->setFileEntries(std::begin(fileEntries), std::end(fileEntries));
     dctx_->setPieceLength(pieceLength);
     peerStorage_.reset(new MockPeerStorage());
     btRuntime_.reset(new BtRuntime());
@@ -111,14 +114,14 @@ CPPUNIT_TEST_SUITE_REGISTRATION(DefaultBtProgressInfoFileTest);
 #ifndef WORDS_BIGENDIAN
 void DefaultBtProgressInfoFileTest::testLoad_compat()
 {
-  initializeMembers(1024, 81920);
-  dctx_->setBasePath(A2_TEST_DIR"/load");
+  initializeMembers(1_k, 80_k);
+  dctx_->setBasePath(A2_TEST_DIR "/load");
 
   DefaultBtProgressInfoFile infoFile(dctx_, pieceStorage_, option_.get());
   infoFile.setBtRuntime(btRuntime_);
   infoFile.setPeerStorage(peerStorage_);
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/load.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/load.aria2"),
                        infoFile.getFilename());
 
   infoFile.load();
@@ -126,46 +129,46 @@ void DefaultBtProgressInfoFileTest::testLoad_compat()
   // check the contents of objects
 
   // total length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920, dctx_->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)80_k, dctx_->getTotalLength());
 
   // upload length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)1024, btRuntime_->getUploadLengthAtStartup());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, btRuntime_->getUploadLengthAtStartup());
 
   // bitfield
-  CPPUNIT_ASSERT_EQUAL(std::string("fffffffffffffffffffe"),
-                       util::toHex(bitfield_->getBitfield(),
-                                   bitfield_->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("fffffffffffffffffffe"),
+      util::toHex(bitfield_->getBitfield(), bitfield_->getBitfieldLength()));
 
   // the number of in-flight pieces
-  CPPUNIT_ASSERT_EQUAL((size_t)2,
-                       pieceStorage_->countInFlightPiece());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieceStorage_->countInFlightPiece());
 
   // piece index 1
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   pieceStorage_->getInFlightPieces(inFlightPieces);
 
-  SharedHandle<Piece> piece1 = inFlightPieces[0];
+  std::shared_ptr<Piece> piece1 = inFlightPieces[0];
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)1024, piece1->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, piece1->getLength());
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getBitfieldLength());
-  CPPUNIT_ASSERT_EQUAL(std::string("00"), util::toHex(piece1->getBitfield(),
-                                                      piece1->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("00"),
+      util::toHex(piece1->getBitfield(), piece1->getBitfieldLength()));
 
   // piece index 2
-  SharedHandle<Piece> piece2 = inFlightPieces[1];
+  std::shared_ptr<Piece> piece2 = inFlightPieces[1];
   CPPUNIT_ASSERT_EQUAL((size_t)2, piece2->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)512, piece2->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)512, piece2->getLength());
 }
 #endif // !WORDS_BIGENDIAN
 
 void DefaultBtProgressInfoFileTest::testLoad()
 {
-  initializeMembers(1024, 81920);
+  initializeMembers(1_k, 80_k);
 
-  dctx_->setBasePath(A2_TEST_DIR"/load-v0001");
+  dctx_->setBasePath(A2_TEST_DIR "/load-v0001");
 
   DefaultBtProgressInfoFile infoFile(dctx_, pieceStorage_, option_.get());
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/load-v0001.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/load-v0001.aria2"),
                        infoFile.getFilename());
   infoFile.setBtRuntime(btRuntime_);
   infoFile.setPeerStorage(peerStorage_);
@@ -175,61 +178,60 @@ void DefaultBtProgressInfoFileTest::testLoad()
   // check the contents of objects
 
   // total length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920, dctx_->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)80_k, dctx_->getTotalLength());
 
   // upload length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)1024, btRuntime_->getUploadLengthAtStartup());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, btRuntime_->getUploadLengthAtStartup());
 
   // bitfield
-  CPPUNIT_ASSERT_EQUAL(std::string("fffffffffffffffffffe"),
-                       util::toHex(bitfield_->getBitfield(),
-                                   bitfield_->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("fffffffffffffffffffe"),
+      util::toHex(bitfield_->getBitfield(), bitfield_->getBitfieldLength()));
 
   // the number of in-flight pieces
-  CPPUNIT_ASSERT_EQUAL((size_t)2,
-                       pieceStorage_->countInFlightPiece());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieceStorage_->countInFlightPiece());
 
   // piece index 1
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   pieceStorage_->getInFlightPieces(inFlightPieces);
 
-  SharedHandle<Piece> piece1 = inFlightPieces[0];
+  std::shared_ptr<Piece> piece1 = inFlightPieces[0];
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)1024, piece1->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, piece1->getLength());
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getBitfieldLength());
-  CPPUNIT_ASSERT_EQUAL(std::string("00"), util::toHex(piece1->getBitfield(),
-                                                      piece1->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("00"),
+      util::toHex(piece1->getBitfield(), piece1->getBitfieldLength()));
 
   // piece index 2
-  SharedHandle<Piece> piece2 = inFlightPieces[1];
+  std::shared_ptr<Piece> piece2 = inFlightPieces[1];
   CPPUNIT_ASSERT_EQUAL((size_t)2, piece2->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)512, piece2->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)512, piece2->getLength());
 }
 
 void DefaultBtProgressInfoFileTest::testSave()
 {
-  initializeMembers(1024, 81920);
+  initializeMembers(1_k, 80_k);
 
-  dctx_->setBasePath(A2_TEST_OUT_DIR"/save-temp");
+  dctx_->setBasePath(A2_TEST_OUT_DIR "/save-temp");
+  dctx_->getNetStat().updateUpload(768);
+  btRuntime_->setUploadLengthAtStartup(256);
   bitfield_->setAllBit();
   bitfield_->unsetBit(79);
   pieceStorage_->setCompletedLength(80896);
-  TransferStat stat;
-  stat.setAllTimeUploadLength(1024);
-  peerStorage_->setStat(stat);
 
-  SharedHandle<Piece> p1(new Piece(1, 1024));
-  SharedHandle<Piece> p2(new Piece(2, 512));
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::shared_ptr<Piece> p1(new Piece(1, 1_k));
+  std::shared_ptr<Piece> p2(new Piece(2, 512));
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   inFlightPieces.push_back(p1);
   inFlightPieces.push_back(p2);
   pieceStorage_->addInFlightPiece(inFlightPieces);
-  
+
   DefaultBtProgressInfoFile infoFile(dctx_, pieceStorage_, option_.get());
   infoFile.setBtRuntime(btRuntime_);
   infoFile.setPeerStorage(peerStorage_);
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_OUT_DIR"/save-temp.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_OUT_DIR "/save-temp.aria2"),
                        infoFile.getFilename());
 
   infoFile.save();
@@ -237,7 +239,7 @@ void DefaultBtProgressInfoFileTest::testSave()
   // read and validate
   std::ifstream in(infoFile.getFilename().c_str(), std::ios::binary);
 
-  //in.exceptions(ios::failbit);
+  // in.exceptions(ios::failbit);
 
   unsigned char version[2];
   in.read((char*)version, sizeof(version));
@@ -262,17 +264,17 @@ void DefaultBtProgressInfoFileTest::testSave()
   uint32_t pieceLength;
   in.read((char*)&pieceLength, sizeof(pieceLength));
   pieceLength = ntohl(pieceLength);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)1024, pieceLength);
+  CPPUNIT_ASSERT_EQUAL((uint32_t)1_k, pieceLength);
 
   uint64_t totalLength;
   in.read((char*)&totalLength, sizeof(totalLength));
   totalLength = ntoh64(totalLength);
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920/* 80*1024 */, totalLength);
+  CPPUNIT_ASSERT_EQUAL((uint64_t)80_k, totalLength);
 
   uint64_t uploadLength;
   in.read((char*)&uploadLength, sizeof(uploadLength));
   uploadLength = ntoh64(uploadLength);
-  CPPUNIT_ASSERT_EQUAL((uint64_t)1024, uploadLength);
+  CPPUNIT_ASSERT_EQUAL((uint64_t)1_k, uploadLength);
 
   uint32_t bitfieldLength;
   in.read((char*)&bitfieldLength, sizeof(bitfieldLength));
@@ -298,7 +300,7 @@ void DefaultBtProgressInfoFileTest::testSave()
   uint32_t pieceLength1;
   in.read((char*)&pieceLength1, sizeof(pieceLength1));
   pieceLength1 = ntohl(pieceLength1);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)1024, pieceLength1);
+  CPPUNIT_ASSERT_EQUAL((uint32_t)1_k, pieceLength1);
 
   uint32_t pieceBitfieldLength1;
   in.read((char*)&pieceBitfieldLength1, sizeof(pieceBitfieldLength1));
@@ -329,148 +331,147 @@ void DefaultBtProgressInfoFileTest::testSave()
 #ifndef WORDS_BIGENDIAN
 void DefaultBtProgressInfoFileTest::testLoad_nonBt_compat()
 {
-  initializeMembers(1024, 81920);
+  initializeMembers(1_k, 80_k);
+
+  std::shared_ptr<DownloadContext> dctx(
+      new DownloadContext(1_k, 80_k, A2_TEST_DIR "/load-nonBt"));
 
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 81920, A2_TEST_DIR"/load-nonBt"));
-  
   DefaultBtProgressInfoFile infoFile(dctx, pieceStorage_, option_.get());
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/load-nonBt.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/load-nonBt.aria2"),
                        infoFile.getFilename());
   infoFile.load();
 
   // check the contents of objects
 
   // total length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920, dctx->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)80_k, dctx->getTotalLength());
 
   // bitfield
-  CPPUNIT_ASSERT_EQUAL(std::string("fffffffffffffffffffe"),
-                       util::toHex(bitfield_->getBitfield(),
-                                   bitfield_->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("fffffffffffffffffffe"),
+      util::toHex(bitfield_->getBitfield(), bitfield_->getBitfieldLength()));
 
   // the number of in-flight pieces
-  CPPUNIT_ASSERT_EQUAL((size_t)2,
-                       pieceStorage_->countInFlightPiece());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieceStorage_->countInFlightPiece());
 
   // piece index 1
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   pieceStorage_->getInFlightPieces(inFlightPieces);
 
-  SharedHandle<Piece> piece1 = inFlightPieces[0];
+  std::shared_ptr<Piece> piece1 = inFlightPieces[0];
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)1024, piece1->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, piece1->getLength());
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getBitfieldLength());
-  CPPUNIT_ASSERT_EQUAL(std::string("00"), util::toHex(piece1->getBitfield(),
-                                                      piece1->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("00"),
+      util::toHex(piece1->getBitfield(), piece1->getBitfieldLength()));
 
   // piece index 2
-  SharedHandle<Piece> piece2 = inFlightPieces[1];
+  std::shared_ptr<Piece> piece2 = inFlightPieces[1];
   CPPUNIT_ASSERT_EQUAL((size_t)2, piece2->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)512, piece2->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)512, piece2->getLength());
 }
 #endif // !WORDS_BIGENDIAN
 
 void DefaultBtProgressInfoFileTest::testLoad_nonBt()
 {
-  initializeMembers(1024, 81920);
+  initializeMembers(1_k, 80_k);
+
+  std::shared_ptr<DownloadContext> dctx(
+      new DownloadContext(1_k, 80_k, A2_TEST_DIR "/load-nonBt-v0001"));
 
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 81920, A2_TEST_DIR"/load-nonBt-v0001"));
-  
   DefaultBtProgressInfoFile infoFile(dctx, pieceStorage_, option_.get());
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/load-nonBt-v0001.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/load-nonBt-v0001.aria2"),
                        infoFile.getFilename());
   infoFile.load();
 
   // check the contents of objects
 
   // total length
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920, dctx->getTotalLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)80_k, dctx->getTotalLength());
 
   // bitfield
-  CPPUNIT_ASSERT_EQUAL(std::string("fffffffffffffffffffe"),
-                       util::toHex(bitfield_->getBitfield(),
-                                   bitfield_->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("fffffffffffffffffffe"),
+      util::toHex(bitfield_->getBitfield(), bitfield_->getBitfieldLength()));
 
   // the number of in-flight pieces
-  CPPUNIT_ASSERT_EQUAL((size_t)2,
-                       pieceStorage_->countInFlightPiece());
+  CPPUNIT_ASSERT_EQUAL((size_t)2, pieceStorage_->countInFlightPiece());
 
   // piece index 1
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   pieceStorage_->getInFlightPieces(inFlightPieces);
 
-  SharedHandle<Piece> piece1 = inFlightPieces[0];
+  std::shared_ptr<Piece> piece1 = inFlightPieces[0];
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)1024, piece1->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)1_k, piece1->getLength());
   CPPUNIT_ASSERT_EQUAL((size_t)1, piece1->getBitfieldLength());
-  CPPUNIT_ASSERT_EQUAL(std::string("00"), util::toHex(piece1->getBitfield(),
-                                                      piece1->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("00"),
+      util::toHex(piece1->getBitfield(), piece1->getBitfieldLength()));
 
   // piece index 2
-  SharedHandle<Piece> piece2 = inFlightPieces[1];
+  std::shared_ptr<Piece> piece2 = inFlightPieces[1];
   CPPUNIT_ASSERT_EQUAL((size_t)2, piece2->getIndex());
-  CPPUNIT_ASSERT_EQUAL((size_t)512, piece2->getLength());
+  CPPUNIT_ASSERT_EQUAL((int64_t)512, piece2->getLength());
 }
 
 void DefaultBtProgressInfoFileTest::testLoad_nonBt_pieceLengthShorter()
 {
-  initializeMembers(512, 81920);
+  initializeMembers(512, 80_k);
   option_->put(PREF_ALLOW_PIECE_LENGTH_CHANGE, A2_V_TRUE);
 
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(512, 81920, A2_TEST_DIR"/load-nonBt-v0001"));
+  std::shared_ptr<DownloadContext> dctx(
+      new DownloadContext(512, 80_k, A2_TEST_DIR "/load-nonBt-v0001"));
 
   DefaultBtProgressInfoFile infoFile(dctx, pieceStorage_, option_.get());
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/load-nonBt-v0001.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/load-nonBt-v0001.aria2"),
                        infoFile.getFilename());
   infoFile.load();
 
   // check the contents of objects
 
   // bitfield
-  CPPUNIT_ASSERT_EQUAL(std::string("fffffffffffffffffffffffffffffffffffffffc"),
-                       util::toHex(bitfield_->getBitfield(),
-                                   bitfield_->getBitfieldLength()));
+  CPPUNIT_ASSERT_EQUAL(
+      std::string("fffffffffffffffffffffffffffffffffffffffc"),
+      util::toHex(bitfield_->getBitfield(), bitfield_->getBitfieldLength()));
 
   // the number of in-flight pieces
-  CPPUNIT_ASSERT_EQUAL((size_t)0,
-                       pieceStorage_->countInFlightPiece());
+  CPPUNIT_ASSERT_EQUAL((size_t)0, pieceStorage_->countInFlightPiece());
 }
 
 void DefaultBtProgressInfoFileTest::testSave_nonBt()
 {
-  initializeMembers(1024, 81920);
+  initializeMembers(1_k, 80_k);
 
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 81920, A2_TEST_OUT_DIR"/save-temp"));
+  std::shared_ptr<DownloadContext> dctx(
+      new DownloadContext(1_k, 80_k, A2_TEST_OUT_DIR "/save-temp"));
 
   bitfield_->setAllBit();
   bitfield_->unsetBit(79);
   pieceStorage_->setCompletedLength(80896);
 
-  SharedHandle<Piece> p1(new Piece(1, 1024));
-  SharedHandle<Piece> p2(new Piece(2, 512));
-  std::vector<SharedHandle<Piece> > inFlightPieces;
+  std::shared_ptr<Piece> p1(new Piece(1, 1_k));
+  std::shared_ptr<Piece> p2(new Piece(2, 512));
+  std::vector<std::shared_ptr<Piece>> inFlightPieces;
   inFlightPieces.push_back(p1);
   inFlightPieces.push_back(p2);
   pieceStorage_->addInFlightPiece(inFlightPieces);
-  
+
   DefaultBtProgressInfoFile infoFile(dctx, pieceStorage_, option_.get());
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_OUT_DIR"/save-temp.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_OUT_DIR "/save-temp.aria2"),
                        infoFile.getFilename());
 
   infoFile.save();
-  
+
   // read and validate
   std::ifstream in(infoFile.getFilename().c_str(), std::ios::binary);
 
-  //in.exceptions(ios::failbit);
+  // in.exceptions(ios::failbit);
 
   unsigned char version[2];
   in.read((char*)version, sizeof(version));
@@ -490,12 +491,12 @@ void DefaultBtProgressInfoFileTest::testSave_nonBt()
   uint32_t pieceLength;
   in.read((char*)&pieceLength, sizeof(pieceLength));
   pieceLength = ntohl(pieceLength);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)1024, pieceLength);
-  
+  CPPUNIT_ASSERT_EQUAL((uint32_t)1_k, pieceLength);
+
   uint64_t totalLength;
   in.read((char*)&totalLength, sizeof(totalLength));
   totalLength = ntoh64(totalLength);
-  CPPUNIT_ASSERT_EQUAL((uint64_t)81920/* 80*1024 */, totalLength);
+  CPPUNIT_ASSERT_EQUAL((uint64_t)80_k, totalLength);
 
   uint64_t uploadLength;
   in.read((char*)&uploadLength, sizeof(uploadLength));
@@ -526,7 +527,7 @@ void DefaultBtProgressInfoFileTest::testSave_nonBt()
   uint32_t pieceLength1;
   in.read((char*)&pieceLength1, sizeof(pieceLength1));
   pieceLength1 = ntohl(pieceLength1);
-  CPPUNIT_ASSERT_EQUAL((uint32_t)1024, pieceLength1);
+  CPPUNIT_ASSERT_EQUAL((uint32_t)1_k, pieceLength1);
 
   uint32_t pieceBitfieldLength1;
   in.read((char*)&pieceBitfieldLength1, sizeof(pieceBitfieldLength1));
@@ -548,31 +549,31 @@ void DefaultBtProgressInfoFileTest::testSave_nonBt()
   in.read((char*)&pieceLength2, sizeof(pieceLength2));
   pieceLength2 = ntohl(pieceLength2);
   CPPUNIT_ASSERT_EQUAL((uint32_t)512, pieceLength2);
-
 }
 
 void DefaultBtProgressInfoFileTest::testUpdateFilename()
 {
-  SharedHandle<DownloadContext> dctx
-    (new DownloadContext(1024, 81920, A2_TEST_DIR"/file1"));
+  std::shared_ptr<DownloadContext> dctx(
+      new DownloadContext(1_k, 80_k, A2_TEST_DIR "/file1"));
 
-  DefaultBtProgressInfoFile infoFile(dctx, SharedHandle<MockPieceStorage>(), 0);
+  DefaultBtProgressInfoFile infoFile(dctx, std::shared_ptr<MockPieceStorage>(),
+                                     nullptr);
 #ifdef ENABLE_BITTORRENT
   infoFile.setBtRuntime(btRuntime_);
   infoFile.setPeerStorage(peerStorage_);
 #endif // ENABLE_BITTORRENT
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/file1.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/file1.aria2"),
                        infoFile.getFilename());
 
-  dctx->getFirstFileEntry()->setPath(A2_TEST_DIR"/file1.1");
+  dctx->getFirstFileEntry()->setPath(A2_TEST_DIR "/file1.1");
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/file1.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/file1.aria2"),
                        infoFile.getFilename());
 
   infoFile.updateFilename();
 
-  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR"/file1.1.aria2"),
+  CPPUNIT_ASSERT_EQUAL(std::string(A2_TEST_DIR "/file1.1.aria2"),
                        infoFile.getFilename());
 }
 
