@@ -5,32 +5,33 @@
 #include "array_fun.h"
 #include "BitfieldMan.h"
 #include "MockPieceSelector.h"
+#include "a2functional.h"
 
 namespace aria2 {
 
-class PriorityPieceSelectorTest:public CppUnit::TestFixture {
+class PriorityPieceSelectorTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(PriorityPieceSelectorTest);
   CPPUNIT_TEST(testSelect);
   CPPUNIT_TEST_SUITE_END();
+
 public:
   void testSelect();
 };
 
-
 CPPUNIT_TEST_SUITE_REGISTRATION(PriorityPieceSelectorTest);
 
 void PriorityPieceSelectorTest::testSelect()
 {
-  size_t pieceLength = 1024;
-  size_t A[] = { 1,200};
-  BitfieldMan bf(pieceLength, pieceLength*256);
-  for(size_t i = 0; i < arrayLength(A); ++i) {
-    bf.setBit(A[i]);
+  constexpr size_t pieceLength = 1_k;
+  size_t A[] = {1, 200};
+  BitfieldMan bf(pieceLength, pieceLength * 256);
+  for (auto i : A) {
+    bf.setBit(i);
   }
-  PriorityPieceSelector selector
-    (SharedHandle<PieceSelector>(new MockPieceSelector()));
-  selector.setPriorityPiece(&A[0], &A[arrayLength(A)]);
+  PriorityPieceSelector selector(
+      std::shared_ptr<PieceSelector>(new MockPieceSelector()));
+  selector.setPriorityPiece(std::begin(A), std::end(A));
 
   size_t index;
   CPPUNIT_ASSERT(selector.select(index, bf.getBitfield(), bf.countBlock()));
